@@ -157,7 +157,7 @@ static void edit_super_block (reiserfs_filsys_t * fs)
 		strncpy (fs->fs_ondisk_sb->s_v1.s_magic, str, n > 10 ? 10 : n);
     
     /* __u16 sb_fsck_state; */
-    printf ("\tFielsystem state: current: %u: new:", get_sb_fs_state (fs->fs_ondisk_sb));
+    printf ("\tFilesystem state: current: %u: new:", get_sb_fs_state (fs->fs_ondisk_sb));
     getline (&str, &n, stdin);
     if (str2int (str, &num))
 		set_sb_fs_state (fs->fs_ondisk_sb, num);
@@ -489,7 +489,8 @@ void do_one_corruption_in_one_block (reiserfs_filsys_t * fs,
 							  "not so many unfm ptrs in it\n");
 			return;
 	    }
-	    * ((__u32 *)B_I_PITEM (bh, ih) + pos_in_item) = get_sb_block_count (fs->fs_ondisk_sb) + 100;
+	    d32_put((__u32 *)B_I_PITEM (bh, ih), pos_in_item, 
+		    get_sb_block_count (fs->fs_ondisk_sb) + 100);
 	    break;
 	    
 	case 'D': /* delete item */
@@ -727,7 +728,7 @@ void do_leaves_corruption (reiserfs_filsys_t * fs,
 	}
 
     if (reiserfs_open_ondisk_bitmap (fs) < 0)
-		reiserfs_panic ("Could not open ondisk bitmap");
+		reiserfs_exit (1, "Could not open ondisk bitmap");
 
     for (i = 0; (i < get_sb_block_count (fs->fs_ondisk_sb)) &&
 			 nr_leaves < nr_leaves_cr; i ++) {
@@ -808,7 +809,7 @@ void do_bitmap_corruption (reiserfs_filsys_t * fs)
 	struct buffer_head * bh;
 	unsigned int i;
 
-	nr_bitmap_to_corrupt = (unsigned long)get_rand (1, get_sb_bmap_nr (fs->fs_ondisk_sb) - 1);
+	nr_bitmap_to_corrupt = (unsigned long)get_rand (1, reiserfs_fs_bmap_nr(fs) - 1);
 
 	if ((data(fs)->log_file_name) && (data(fs)->log)) {
 		fprintf (data(fs)->log, "%lu bitmaps will be corrupted\n", nr_bitmap_to_corrupt);
@@ -852,7 +853,7 @@ void do_ih_random_corrupt (reiserfs_filsys_t * fs,
 	}
 
     if (reiserfs_open_ondisk_bitmap (fs) < 0)
-		reiserfs_panic ("Could not open ondisk bitmap");
+		reiserfs_exit (1, "Could not open ondisk bitmap");
 
     for (i = 0; (i < get_sb_block_count (fs->fs_ondisk_sb)) &&
 			 nr_leaves < nr_leaves_cr; i ++) {
@@ -959,7 +960,7 @@ void do_dir_random_corrupt (reiserfs_filsys_t * fs,
 	}
 
     if (reiserfs_open_ondisk_bitmap (fs) < 0)
-		reiserfs_panic ("Could not open ondisk bitmap");
+		reiserfs_exit (1, "Could not open ondisk bitmap");
 
     for (i = 0; (i < get_sb_block_count (fs->fs_ondisk_sb)) &&
 			 nr_leaves < nr_leaves_cr; i ++) {
@@ -1040,7 +1041,7 @@ void do_sd_random_corrupt (reiserfs_filsys_t * fs,
 	}
 
     if (reiserfs_open_ondisk_bitmap (fs) < 0)
-		reiserfs_panic ("Could not open ondisk bitmap");
+		reiserfs_exit (1, "Could not open ondisk bitmap");
 
     for (i = 0; (i < get_sb_block_count (fs->fs_ondisk_sb)) &&
 			 nr_leaves < nr_leaves_cr; i ++) {
@@ -1121,7 +1122,7 @@ void do_ind_random_corrupt (reiserfs_filsys_t * fs,
 	}
 
     if (reiserfs_open_ondisk_bitmap (fs) < 0)
-		reiserfs_panic ("Could not open ondisk bitmap");
+		reiserfs_exit (1, "Could not open ondisk bitmap");
 
     for (i = 0; (i < get_sb_block_count (fs->fs_ondisk_sb)) &&
 			 nr_leaves < nr_leaves_cr; i ++) {
